@@ -4,7 +4,7 @@ var $j= jQuery.noConflict();
 
 $j(document).ready( function () {
 
-    $j("#tabs").tabs({event:"mouseover"});
+    $j("#tabs").tabs();
     $j("#accordion").accordion({fillSpace:"true"});
 
     var rootScenario = new PNI.Scenario({id:"root"});
