@@ -2,9 +2,12 @@ package PNI::Set;
 use PNI::Mo;
 extends 'PNI::Elem';
 
+# TODO: change to this ... has elem => ( default => sub { return {}; } );
 has elem => ( default => sub { +{} } );
-has min  => ( default => sub { 0 } );
-has max  => ( default => sub { 0 } );
+has min  => ( default => sub { return 0; } );
+
+# TODO perlcritic should complain
+has max => ( default => sub { 0 } );
 
 sub add {
     my $self = shift;
@@ -12,23 +15,28 @@ sub add {
         scalar( $self->list ) < $self->max or return;
     }
     my $elem = shift or return;
-    $self->elem->{ $elem->id } = $elem;
+    return $self->elem->{ $elem->id } = $elem;
 }
 
+# TODO consider to add ... sub cardinality { return scalar( shift->list ); }
+
 sub del {
     my $self = shift;
     if ( $self->min ) {
         scalar( $self->list ) > $self->min or return;
     }
     my $elem = shift or return;
-    delete $self->elem->{ $elem->id };
+    return delete $self->elem->{ $elem->id };
 }
 
-sub ids { keys %{ shift->elem } }
+sub ids { return keys %{ shift->elem } }
 
-sub list { values %{ shift->elem } }
+sub list { return values %{ shift->elem } }
+
+# TODO ma devo mettere Return the element oppure Returns con la s ?
+
+1;
 
-1
 __END__
 
 =head1 NAME
@@ -47,12 +55,19 @@ PNI::Set - is a set of elements
 
     $set->list;    # ($elem1,$elem2)
 
+    my $elem1_id = $elem1->id;
+    $set->elem->{$elem1_id};     # $elem1
+
 =head1 ATTRIBUTES
 
 =head2 elem
 
+    my $elem_hashref = $set->elem;
+
 Hash of elements contained in this L<PNI::Set>.
 
+    my $elem_foo = $set->elem->{'foo_id'};
+
 =head2 min
 
 Minimum number of elements: default is 0.
@@ -80,13 +95,13 @@ Remove a L<PNI::Elem> from this L<PNI::Set>.
 
     my @ids = $set->ids;
 
-Return a list containing every C<id> of this set elements.
+Return a list containing every C<id> of the elements cointained in the set.
 
 =head2 list
 
     my @elems = $set->list;
 
-    my $num_elems = scalar( $set->list );
+Return a list containing every C<element> of the set.
 
 =cut
 
